window.Gleam.initSearch([{"doc":"wasmify","title":"wasmify","content":"# wasmify\n\n[![Package Version](https://img.shields.io/hexpm/v/wasmify)](https://hex.pm/packages/wasmify)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/wasmify/)\n\nUse WASM in Gleam !\n\n## Usage\n(see [`/example/src/example.gleam`](https://github.com/endercheif/wasmify/blob/master/example/src/example.gleam) for a demo)\n\ndecompiled `math.wasm`\n```wasm\n(module\n  (import &quot;gleam&quot; &quot;print&quot; (func $print (param f32) (result f32)))\n  (func (export &quot;pythagorean&quot;) (param f32 f32) (result f32)\n    (local $x f32)\n    (local $y f32)\n\n    local.get 0\n    local.get 0\n    f32.mul\n    local.set $x\n\n    local.get 1\n    local.get 1\n    f32.mul\n    local.set $y\n\n    local.get $x\n    local.get $y\n   \t\n    f32.add\n\tf32.sqrt\n\n    call $print\n  )\n)\n\n```\n\n`mod.gleam`\n```gleam\nimport gleam/float\nimport wasmify/types.{Get}\nimport wasmify/wasm.{function, get, instance, load_wasm, load_wasm_sync, module, namespace} // load_wasm_sync only works in non browser runtimes and returns Result(Promise(file), String)\n\nfn print_float(value: Float) -&gt; Float {\n  io.println(&quot;result is: &quot; &lt;&gt; float.to_string(value))\n  value\n}\n\npub fn main() {\n    let assert Ok(file) = load_wasm_sync\n    let wasm = module(file) |&gt; instance([namespace(&quot;gleam&quot;, [#(&quot;print&quot;, function(print_int))])])\n\n    let assert Ok(pythagorean): Get(fn (Float, Float) -&gt; Float) = get(wasm, &quot;pythagorean&quot;)\n\n    let res = pythagorean(3.0, 4.0)\n\n    case 5.0 == pythagorean(3.0, 4.0) {\n        True -&gt; io.print(&quot;all good!&quot;)\n        False -&gt; panic\n    }\n}\n\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add wasmify\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/wasmify&gt;.\n","url":"index.html"},{"doc":"wasmify/types","title":"Get","content":"pub type Get(t) =\n  Result(t, Nil)\n Shorthand for typing return types of exports\n\nSynonyms:\nwasmify/types.Get\nwasmify/types Get","url":"wasmify/types.html#Get"},{"doc":"wasmify/types","title":"Global","content":"pub type Global\n\n\nSynonyms:\nwasmify/types.Global\nwasmify/types Global","url":"wasmify/types.html#Global"},{"doc":"wasmify/types","title":"GlobalVar","content":"pub type GlobalVar\n\n\nSynonyms:\nwasmify/types.GlobalVar\nwasmify/types GlobalVar","url":"wasmify/types.html#GlobalVar"},{"doc":"wasmify/types","title":"Imports","content":"pub type Imports\n\n\nSynonyms:\nwasmify/types.Imports\nwasmify/types Imports","url":"wasmify/types.html#Imports"},{"doc":"wasmify/types","title":"Uint8Array","content":"pub type Uint8Array\n\n\nSynonyms:\nwasmify/types.Uint8Array\nwasmify/types Uint8Array","url":"wasmify/types.html#Uint8Array"},{"doc":"wasmify/types","title":"WebAssemblyInstance","content":"pub type WebAssemblyInstance\n\n\nSynonyms:\nwasmify/types.WebAssemblyInstance\nwasmify/types WebAssemblyInstance","url":"wasmify/types.html#WebAssemblyInstance"},{"doc":"wasmify/types","title":"WebAssemblyModule","content":"pub type WebAssemblyModule\n\n\nSynonyms:\nwasmify/types.WebAssemblyModule\nwasmify/types WebAssemblyModule","url":"wasmify/types.html#WebAssemblyModule"},{"doc":"wasmify/types","title":"wasmify/types","content":"","url":"wasmify/types.html"},{"doc":"wasmify/global","title":"f32","content":"pub fn f32(value: Float, mutable: Bool) -&gt; Global\n\nSynonyms:\nwasmify/global.f32\nwasmify/global f32","url":"wasmify/global.html#f32"},{"doc":"wasmify/global","title":"f64","content":"pub fn f64(value: Float, mutable: Bool) -&gt; Global\n\nSynonyms:\nwasmify/global.f64\nwasmify/global f64","url":"wasmify/global.html#f64"},{"doc":"wasmify/global","title":"i32","content":"pub fn i32(value: Int, mutable: Bool) -&gt; Global\n\nSynonyms:\nwasmify/global.i32\nwasmify/global i32","url":"wasmify/global.html#i32"},{"doc":"wasmify/global","title":"i64","content":"pub fn i64(value: Int, mutable: Bool) -&gt; Global\n\nSynonyms:\nwasmify/global.i64\nwasmify/global i64","url":"wasmify/global.html#i64"},{"doc":"wasmify/global","title":"v128","content":"pub fn v128(value: a, mutable: Bool) -&gt; Global\n\nSynonyms:\nwasmify/global.v128\nwasmify/global v128","url":"wasmify/global.html#v128"},{"doc":"wasmify/global","title":"wasmify/global","content":"","url":"wasmify/global.html"},{"doc":"wasmify","title":"function","content":"pub fn function(v: a) -&gt; Imports\n Converts a function to be accessable in WASM\nSynonyms:\nwasmify.function\nwasmify function","url":"wasmify.html#function"},{"doc":"wasmify","title":"get","content":"pub fn get(instance: WebAssemblyInstance, name: String) -&gt; Result(\n  a,\n  Nil,\n)\n Get a exported function (if it exists)\nSynonyms:\nwasmify.get\nwasmify get","url":"wasmify.html#get"},{"doc":"wasmify","title":"instance","content":"pub fn instance(module: WebAssemblyModule, imports: List(Imports)) -&gt; WebAssemblyInstance\n Create an Instance and supply imports to be acessed in WebAssembly\nSynonyms:\nwasmify.instance\nwasmify instance","url":"wasmify.html#instance"},{"doc":"wasmify","title":"load_wasm","content":"pub fn load_wasm(path: String) -&gt; Result(\n  Promise(Uint8Array),\n  String,\n)\n Asynchronous load *.wasm as a Uint8Array/Buffer\n Error can occur if the file does not exist. Should work in all JavaScript runtimes\nSynonyms:\nwasmify.load_wasm\nwasmify load_wasm","url":"wasmify.html#load_wasm"},{"doc":"wasmify","title":"load_wasm_sync","content":"pub fn load_wasm_sync(path: String) -&gt; Result(Uint8Array, String)\n Syncronously load *.wasm as a Uint8Array/Buffer\n Error can occur if the file does not exist. Only works in Deno, NodeJS (commonjs), and Bun. \nSynonyms:\nwasmify.load_wasm_sync\nwasmify load_wasm_sync","url":"wasmify.html#load_wasm_sync"},{"doc":"wasmify","title":"module","content":"pub fn module(content: Uint8Array) -&gt; WebAssemblyModule\n Create a WebAssembly Module\nSynonyms:\nwasmify.module\nwasmify module","url":"wasmify.html#module"},{"doc":"wasmify","title":"namespace","content":"pub fn namespace(name: String, o: List(#(String, Imports))) -&gt; Imports\n\nSynonyms:\nwasmify.namespace\nwasmify namespace","url":"wasmify.html#namespace"},{"doc":"wasmify","title":"wasmify","content":"","url":"wasmify.html"}]);